<!-- -*- mode: markdown; mode: flyspell -*- -->

# bash-range-expand library

A simple library to expand numeric ranges. A range are two numbers
separated by a dash. E.g. "10-12" would expand to "10 11 12". It
supports macros which enables to use names for ranges. Any strings
that are no ranges will be copied. Expansion can be extended with
prefixes and suffixes, which will only be added to ranges or numbers.
Macros are read from an associative array called
BRB_RANGE_MACROS. This will change in the future.

This library has only one API function and it exists mainly because it
is used on different places.

## API Docu

```bash
# brp_expand_ranges <prefix> <suffix> <reserved> <input-string> [..]
#  <prefix> and <suffix> are strings without spaces
#  <reserved> is reserved for the name of the macro associative array
#             this will be implemented in a future version
#  <input-string> can be the following:
#    a range (<number>-<number>): will be expanded to each member of range
#                                 prefix and suffix will be added to each
#    a number: prefix and suffix will be added
#    a macro: a string which is key in the associative array BRP_RANGE_MACROS
#             its value will be expanded in recursive fashion
#    any other string (must not contain spaces): will be copied unmodified
```

## Examples

```bash
> brp_expand_ranges "" "" "" 1 2 3
1 2 3

> brp_expand_ranges "pre" "post" "" 1 2 3 
pre1post pre2post pre3post

> brp_expand_ranges "" "post" "" 1-3
1post 2post 3post

> brp_expand_ranges "" "post" "" 1-3 somestring 3
1post 2post 3post somestring 3post

BRB_RANGE_MACROS=([cow]=1-3 [cat]=2-5

> brp_expand_ranges "" "" "" cow
1 2 3

> brp_expand_ranges "" "" "" cat cow
2 3 4 5 1 2 3

BRB_RANGE_MACROS=([cow1]="1-3" [cow2]="4-5" [herd]="cow1 cow2")

> brp_expand_ranges "mooh" "" "" herd
mooh1 mooh2 mooh3 mooh4 mooh5
```
