#!/bin/bash

set -o errexit
set -o pipefail
set -o nounset

ERRORS=0

function fatal() {
    echo "${0##*/}: fatal error: $*"
    exit 1
}

trap 'fatal unexpected exit' EXIT

if [[ -f range-expand.bash ]]
then
    source range-expand.bash
else
    if [[ -f /usr/libexec/bash-range-expand/range-expand.bash ]]
    then
	source /usr/libexec/bash-range-expand/range-expand.bash
    else
	fatal "range-expand.bash not found"
    fi
fi

function check() {
    (( $# == 4 )) || fatal "check called with $# args instead of 4"

    local testname="$1"
    local retval="$2"
    local result="$3"
    local expect="$4"

    (( "$retval" == 0 )) || fatal "$testname failed with $retval"

    if [[ "$result" == "$expect" ]]
    then
	echo "${0##*/}: $testname ok"
    else
	echo "${0##*/}:" \
	    " $testname FAILED (result='$result', expected='$expect')"
	ERRORS=$((ERRORS + 1))
    fi
}

RESULT=$(bre_expand_ranges '' '' '' 1 2 3)
check "123" "$?" "$RESULT" "1 2 3"

RESULT=$(bre_expand_ranges pre post '' 1 2 3)
check "pre123suff" "$?" "$RESULT" "pre1post pre2post pre3post"

RESULT=$(bre_expand_ranges '' post '' 1-3)
check "post1-3" "$?" "$RESULT" "1post 2post 3post"

RESULT=$(bre_expand_ranges '' post '' 1-3 somestring 3)
check "post1-3str3" "$?" "$RESULT" "1post 2post 3post somestring 3post"

declare -A BRE_RANGE_MACROS=([cow]=1-3 [cat]=2-5)

RESULT=$(bre_expand_ranges "" "" "" cow)
check "cow" "$?" "$RESULT" "1 2 3"

RESULT=$(bre_expand_ranges "" "" "" cat cow)
check "catcow" "$?" "$RESULT" "2 3 4 5 1 2 3"

declare -A BRE_RANGE_MACROS=([cow1]="1-3" [cow2]="4-5" [herd]="cow1 cow2")

RESULT=$(bre_expand_ranges "mooh" "" "" herd)
check "recursivecow" "$?" "$RESULT" "mooh1 mooh2 mooh3 mooh4 mooh5"

trap - EXIT
exit "$ERRORS"
